@@ -18,6 +18,7 @@ from hosthome.version import VERSION as __version__
 from hosthome.login import login
 
 url = requests.get("https://raw.githubusercontent.com/HostHome-of/config/main/config.json").json()["url"]
+docs = requests.get("https://raw.githubusercontent.com/HostHome-of/config/main/config.json").json()["docs"]
 
 verbose = False
 
@@ -43,16 +44,27 @@ SI OCURRE UN ERROR PODEIS PONERLO AQUI (https://github.com/HostHome-of/python-CL
 """
 
 def crearArchivo(Lenguage: str, cmd: str):
+  if verbose:
+    print("\n ---- Logs")
+    print("Creando archivo...")
   try:
     data = open(".host.home", "x")
   except:
+    if verbose:
+      print("Archivo localizado")
+      print("Eliminando archivo...")
     os.remove(".host.home")
+    if verbose:
+      print("Recreando...")
     data = open(".host.home", "x")
+  if verbose:
+    print("Escribiendo archivo...")
   archivo2 = str(archivo
-                .replace("tempLen", main)
+                .replace("tempLen", Lenguage)
                 .replace("tempCmdStart", cmd)
                 )
   data.write(archivo2)
+  cprint("¡ya esta!")
 
 def main():
 
@@ -65,10 +77,10 @@ def main():
     if args["empezar"]:    
 
       data = login()
-      cprint(f"> Hola {data['nombre']}", "green")
-      instalacion = input("Pon el comando para comenzar la instalacion :: Ej: npm i ")
+      cprint(f"\nBienvenido {data['nombre']}\n", "green")
+      instalacion = input("Pon el comando para ejecutar el programa :: ")
       mirarSiUsuarioEsImbecil(instalacion)
-      lenguage = input(f"Pon el idioma en el que esta \n * ruby\n * python\n * nodejs\n * scala\n * clojure\n * cs\n * php\n MIRAR DOCS URGENTE ({url}docs) :: ").strip()
+      lenguage = input(f"Pon el idioma en el que esta \n * ruby\n * python\n * nodejs\n * scala\n * clojure\n * cs\n * php\n MIRAR DOCS URGENTE ({docs}) :: ").strip()
       mirarSiUsuarioEsImbecil(lenguage, i=True)
 
       if "--verbose" in args:
